==> 0.0.13.tar.gz: test/antsomi_test.dart <==
import 'package:antsomisdk/catalog.dart';
import 'package:antsomisdk/cdp_event.dart';
import 'package:antsomisdk/inbox_items.dart';
import 'package:antsomisdk/modify_action.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:antsomisdk/antsomi.dart';
import 'package:antsomisdk/antsomi_platform_interface.dart';
import 'package:antsomisdk/antsomi_method_channel.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockAntsomiPlatform
    with MockPlatformInterfaceMixin
    implements AntsomiPlatform {
  @override
  Future<String?> getPlatformVersion() => Future.value('42');

  @override
  Future<bool?> config(
      {String portalId = "",
      String propsId = "",
      String appGroupId = "",
      String applicationId = ""}) {
    // TODO: implement config
    throw UnimplementedError();
  }

  @override
  Future<String?> getUID() {
    // TODO: implement getUID
    throw UnimplementedError();
  }

  @override
  late void Function(InboxItem p1) callback;

  @override
  late void Function(String urlString) deepLinkHandler;

  @override
  void Function()? setDefaultAction;

  @override
  Future appInboxInit({String destinationId = "", String audienceType = ""}) {
    // TODO: implement appInboxInit
    throw UnimplementedError();
  }

  @override
  void configureChannel() {
    // TODO: implement configureChannel
  }

  @override
  Future<List<Catalog>> getAllLabels() {
    // TODO: implement getAllLabels
    throw UnimplementedError();
  }

  @override
  Future<String?> getContext() {
    // TODO: implement getContext
    throw UnimplementedError();
  }

  @override
  Future<String?> getCustomerId() {
    // TODO: implement getCustomerId
    throw UnimplementedError();
  }

  @override
  Future<String?> getDeviceId() {
    // TODO: implement getDeviceId
    throw UnimplementedError();
  }

  @override
  Future<Map<String, String>> getMessageById({required String messageId}) {
    // TODO: implement getMessageById
    throw UnimplementedError();
  }

  @override
  Future<String?> getPortalId() {
    // TODO: implement getPortalId
    throw UnimplementedError();
  }

  @override
  Future<String?> getPropsId() {
    // TODO: implement getPropsId
    throw UnimplementedError();
  }

  @override
  Future<int?> getUnreadMessageCount() {
    // TODO: implement getUnreadMessageCount
    throw UnimplementedError();
  }

  @override
  void modifyAction({required String messageId, required ActionType action}) {
    // TODO: implement modifyAction
  }

  @override
  void onNewMessageReceived(void Function(InboxItem callbackValue)? callback) {
    // TODO: implement onNewMessageReceived
  }

  @override
  Future setCustomerProperties(
      {required String customerId, Map<String, String>? customerProperties}) {
    // TODO: implement setCustomerProperties
    throw UnimplementedError();
  }

  @override
  void track({required CDPEvent event}) {
    // TODO: implement track
  }

  @override
  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], int page = 1}) {
    // TODO: implement getMessage
    throw UnimplementedError();
  }

  @override
  void parseDeepLink(Uri url) {
    // TODO: implement parseDeepLink
  }

  @override
  void setPageLimit({required int limit}) {
    // TODO: implement setPageLimit
  }

  @override
  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    // TODO: implement trackScreen
  }
}

void main() {
  final AntsomiPlatform initialPlatform = AntsomiPlatform.instance;

  test('$MethodChannelAntsomi is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelAntsomi>());
  });

  test('getPlatformVersion', () async {
    Antsomi antsomiPlugin = Antsomi();
    MockAntsomiPlatform fakePlatform = MockAntsomiPlatform();
    AntsomiPlatform.instance = fakePlatform;

    expect(await antsomiPlugin.getPlatformVersion(), '42');
  });
}

==> 0.0.15.tar.gz: test/antsomi_test.dart <==
import 'package:antsomisdk/catalog.dart';
import 'package:antsomisdk/cdp_event.dart';
import 'package:antsomisdk/inbox_items.dart';
import 'package:antsomisdk/modify_action.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:antsomisdk/antsomi.dart';
import 'package:antsomisdk/antsomi_platform_interface.dart';
import 'package:antsomisdk/antsomi_method_channel.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockAntsomiPlatform
    with MockPlatformInterfaceMixin
    implements AntsomiPlatform {
  @override
  Future<String?> getPlatformVersion() => Future.value('42');

  @override
  Future<bool?> config(
      {String portalId = "",
      String propsId = "",
      String appGroupId = "",
      String applicationId = ""}) {
    // TODO: implement config
    throw UnimplementedError();
  }

  @override
  Future<String?> getUID() {
    // TODO: implement getUID
    throw UnimplementedError();
  }

  @override
  late void Function(InboxItem p1) callback;

  @override
  late void Function(String urlString) deepLinkHandler;

  @override
  void Function()? setDefaultAction;

  @override
  Future appInboxInit({String destinationId = "", String audienceType = ""}) {
    // TODO: implement appInboxInit
    throw UnimplementedError();
  }

  @override
  void configureChannel() {
    // TODO: implement configureChannel
  }

  @override
  Future<List<Catalog>> getAllLabels() {
    // TODO: implement getAllLabels
    throw UnimplementedError();
  }

  @override
  Future<String?> getContext() {
    // TODO: implement getContext
    throw UnimplementedError();
  }

  @override
  Future<String?> getCustomerId() {
    // TODO: implement getCustomerId
    throw UnimplementedError();
  }

  @override
  Future<String?> getDeviceId() {
    // TODO: implement getDeviceId
    throw UnimplementedError();
  }

  @override
  Future<Map<String, String>> getMessageById({required String messageId}) {
    // TODO: implement getMessageById
    throw UnimplementedError();
  }

  @override
  Future<String?> getPortalId() {
    // TODO: implement getPortalId
    throw UnimplementedError();
  }

  @override
  Future<String?> getPropsId() {
    // TODO: implement getPropsId
    throw UnimplementedError();
  }

  @override
  Future<int?> getUnreadMessageCount() {
    // TODO: implement getUnreadMessageCount
    throw UnimplementedError();
  }

  @override
  void modifyAction({required String messageId, required int action}) {
    // TODO: implement modifyAction
  }

  @override
  void onNewMessageReceived(void Function(InboxItem callbackValue)? callback) {
    // TODO: implement onNewMessageReceived
  }

  @override
  Future setCustomerProperties(
      {required String customerId, Map<String, String>? customerProperties}) {
    // TODO: implement setCustomerProperties
    throw UnimplementedError();
  }

  @override
  void track({required CDPEvent event}) {
    // TODO: implement track
  }

  @override
  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], int page = 1}) {
    // TODO: implement getMessage
    throw UnimplementedError();
  }

  @override
  void parseDeepLink(Uri url) {
    // TODO: implement parseDeepLink
  }

  @override
  void setPageLimit({required int limit}) {
    // TODO: implement setPageLimit
  }

  @override
  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    // TODO: implement trackScreen
  }
}

void main() {
  final AntsomiPlatform initialPlatform = AntsomiPlatform.instance;

  test('$MethodChannelAntsomi is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelAntsomi>());
  });

  test('getPlatformVersion', () async {
    Antsomi antsomiPlugin = Antsomi();
    MockAntsomiPlatform fakePlatform = MockAntsomiPlatform();
    AntsomiPlatform.instance = fakePlatform;

    expect(await antsomiPlugin.getPlatformVersion(), '42');
  });
}
